@@ -10,12 +10,16 @@
      * model field
      * form field
      * widget
+     
+     INFO: This exist only for backward-compatibility and will be removed
+     in the future. Please use static_path!
 
-    :copyleft: 2010 by the django-tools team, see AUTHORS for more details.
+    :copyleft: 2010-2012 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
 import os
+import warnings
 
 if __name__ == "__main__":
     # For doctest only
@@ -58,8 +62,10 @@ class MediaPathWidget(forms.Select):
     """
     Select a sub directory in settings.MEDIA_ROOT
     
+    >>> import os, django_tools
+    >>> settings.MEDIA_ROOT = os.path.dirname(os.path.abspath(django_tools.__file__))
     >>> MediaPathWidget().choices # doctest: +ELLIPSIS
-    [('/template', '/template'), ..., ('/utils', '/utils')]
+    [('auto_update_cache', 'auto_update_cache'), ..., ('views', 'views')]
     """
     def __init__(self, attrs=None):
         super(MediaPathWidget, self).__init__(attrs)
@@ -73,6 +79,12 @@ class MediaPathWidget(forms.Select):
             if settings.DEBUG:
                 failsafe_message("Can't read MEDIA_ROOT: %s" % err)
 
+        warnings.warn(
+            "MediaPathWidget is deprecated and will removed in the future!"
+            " Please use StaticPathWidget.",
+            PendingDeprecationWarning
+        )
+
     def _get_path_choices(self):
         media_dirs_choices = []
         cut_pos = len(self._base_path)
@@ -97,6 +109,13 @@ class MediaPathModelField(models.TextField):
 
     def formfield(self, **kwargs):
         """ Use always own widget and form field. """
+
+        warnings.warn(
+            "MediaPathModelField is deprecated and will removed in the future!"
+            " Please use StaticPathModelField.",
+            PendingDeprecationWarning
+        )
+
         kwargs["widget"] = MediaPathWidget
 #        kwargs["form_class"] = SignSeparatedFormField
         return super(MediaPathModelField, self).formfield(**kwargs)
@@ -104,7 +123,7 @@ class MediaPathModelField(models.TextField):
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod(
+    print doctest.testmod(
 #        verbose=True
         verbose=False
     )
